/***************************************************************************
                           job_storecustomquery.h
                             -------------------
    begin                : 2005-04-19
    copyright            : (C) 2005 by Markus Kalkbrenner
    email                : mkalkbrenner@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the license, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef JOB_STORECUSTOMQUERY_H
#define JOB_STORECUSTOMQUERY_H

#include "prokyon.h"

#include "jobbase.h"

class Job_StoreCustomQuery : public JobBase  {
public:
    Job_StoreCustomQuery(QString _name, QString _query);

    int type() {
        return JOB_STORE_CUSTOM_QUERY;
    }

    void run();

    ~Job_StoreCustomQuery();

private:
    QString name;
    QString query;
};

#endif
